/*
 * Copyright (C) 2021 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package android.net;

import android.annotation.NonNull;
import android.annotation.SystemApi;
import android.os.Parcel;
import android.os.Parcelable;

import java.util.Objects;

/** @hide */
@SystemApi
public final class EthernetNetworkManagementException
        extends RuntimeException implements Parcelable {

    /* @hide */
    public EthernetNetworkManagementException(@NonNull final String errorMessage) {
        super(errorMessage);
    }

    @Override
    public int hashCode() {
        return Objects.hash(getMessage());
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null || getClass() != obj.getClass()) return false;
        final EthernetNetworkManagementException that = (EthernetNetworkManagementException) obj;

        return Objects.equals(getMessage(), that.getMessage());
    }

    @Override
    public void writeToParcel(@NonNull Parcel dest, int flags) {
        dest.writeString(getMessage());
    }

    @Override
    public int describeContents() {
        return 0;
    }

    @NonNull
    public static final Parcelable.Creator<EthernetNetworkManagementException> CREATOR =
            new Parcelable.Creator<EthernetNetworkManagementException>() {
                @Override
                public EthernetNetworkManagementException[] newArray(int size) {
                    return new EthernetNetworkManagementException[size];
                }

                @Override
                public EthernetNetworkManagementException createFromParcel(@NonNull Parcel source) {
                    return new EthernetNetworkManagementException(source.readString());
                }
            };
}
